"""Zowe Client Python SDK.

This program and the accompanying materials are made available under the terms of the
Eclipse Public License v2.0 which accompanies this distribution, and is available at

https://www.eclipse.org/legal/epl-v20.html

SPDX-License-Identifier: EPL-2.0

Copyright Contributors to the Zowe Project.
"""

from zowe.core_for_zowe_sdk import SdkApi

from .response import ZosmfResponse


class Zosmf(SdkApi):
    """
    Class used to represent the base z/OSMF API.

    Parameters
    ----------
    connection: dict
        The z/OSMF connection object (generated by the ZoweSDK object)
    log : bool
        Flag to disable logger
    """

    def __init__(self, connection: dict, log: bool = True):
        super().__init__(connection, "/zosmf/info", logger_name=__name__, log=log)

    def get_info(self) -> ZosmfResponse:
        """
        Return a JSON response from the GET request to z/OSMF info endpoint.

        Returns
        -------
        ZosmfResponse
            A JSON containing the z/OSMF Info REST API data
        """
        response_json = self.request_handler.perform_request("GET", self._request_arguments)
        return ZosmfResponse(response_json)

    def list_systems(self) -> ZosmfResponse:
        """
        Return a JSON response from the GET request to z/OSMF info endpoint.

        Returns
        -------
        ZosmfResponse
            Return a list of the systems that are defined to a z/OSMF instance
        """
        custom_args = self._create_custom_request_arguments()
        custom_args["url"] = "{}/systems".format(self._request_endpoint)
        response_json = self.request_handler.perform_request("GET", custom_args, expected_code=[200])
        return ZosmfResponse(response_json)
